@@ -1,7 +1,7 @@
 ;;; gnus-soup.el --- SOUP packet writing support for Gnus
 
-;; Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2002, 2003, 2004,
-;;   2005, 2006 Free Software Foundation, Inc.
+;; Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
+;;   2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Author: Per Abrahamsen <abraham@iesd.auc.dk>
 ;;	Lars Magne Ingebrigtsen <larsi@gnus.org>
@@ -11,7 +11,7 @@
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
@@ -36,36 +36,64 @@
 (require 'gnus-start)
 (require 'gnus-range)
 
+(defgroup gnus-soup nil
+  "SOUP packet writing support for Gnus."
+  :group 'gnus)
+
 ;;; User Variables:
 
-(defvar gnus-soup-directory (nnheader-concat gnus-home-directory "SoupBrew/")
-  "*Directory containing an unpacked SOUP packet.")
+(defcustom gnus-soup-directory (nnheader-concat gnus-home-directory "SoupBrew/")
+  "Directory containing an unpacked SOUP packet."
+  :version "22.1" ;; Gnus 5.10.9
+  :type 'directory
+  :group 'gnus-soup)
 
-(defvar gnus-soup-replies-directory
+(defcustom gnus-soup-replies-directory
   (nnheader-concat gnus-soup-directory "SoupReplies/")
-  "*Directory where Gnus will do processing of replies.")
+  "Directory where Gnus will do processing of replies."
+  :version "22.1" ;; Gnus 5.10.9
+  :type 'directory
+  :group 'gnus-soup)
 
-(defvar gnus-soup-prefix-file "gnus-prefix"
-  "*Name of the file where Gnus stores the last used prefix.")
+(defcustom gnus-soup-prefix-file "gnus-prefix"
+  "Name of the file where Gnus stores the last used prefix."
+  :version "22.1" ;; Gnus 5.10.9
+  :type 'file
+  :group 'gnus-soup)
 
-(defvar gnus-soup-packer "tar cf - %s | gzip > $HOME/Soupout%d.tgz"
+(defcustom gnus-soup-packer "tar cf - %s | gzip > $HOME/Soupout%d.tgz"
   "Format string command for packing a SOUP packet.
 The SOUP files will be inserted where the %s is in the string.
 This string MUST contain both %s and %d.  The file number will be
-inserted where %d appears.")
+inserted where %d appears."
+  :version "22.1" ;; Gnus 5.10.9
+  :type 'string
+  :group 'gnus-soup)
 
-(defvar gnus-soup-unpacker "gunzip -c %s | tar xvf -"
-  "*Format string command for unpacking a SOUP packet.
-The SOUP packet file name will be inserted at the %s.")
+(defcustom gnus-soup-unpacker "gunzip -c %s | tar xvf -"
+  "Format string command for unpacking a SOUP packet.
+The SOUP packet file name will be inserted at the %s."
+  :version "22.1" ;; Gnus 5.10.9
+  :type 'string
+  :group 'gnus-soup)
 
-(defvar gnus-soup-packet-directory gnus-home-directory
-  "*Where gnus-soup will look for REPLIES packets.")
+(defcustom gnus-soup-packet-directory gnus-home-directory
+  "Where gnus-soup will look for REPLIES packets."
+  :version "22.1" ;; Gnus 5.10.9
+  :type 'directory
+  :group 'gnus-soup)
 
-(defvar gnus-soup-packet-regexp "Soupin"
-  "*Regular expression matching SOUP REPLIES packets in `gnus-soup-packet-directory'.")
+(defcustom gnus-soup-packet-regexp "Soupin"
+  "Regular expression matching SOUP REPLIES packets in `gnus-soup-packet-directory'."
+  :version "22.1" ;; Gnus 5.10.9
+  :type 'regexp
+  :group 'gnus-soup)
 
-(defvar gnus-soup-ignored-headers "^Xref:"
-  "*Regexp to match headers to be removed when brewing SOUP packets.")
+(defcustom gnus-soup-ignored-headers "^Xref:"
+  "Regexp to match headers to be removed when brewing SOUP packets."
+  :version "22.1" ;; Gnus 5.10.9
+  :type 'regexp
+  :group 'gnus-soup)
 
 ;;; Internal Variables:
 
